import json
import sys

from .ResultBase import ResultBase

class SimpleResult(ResultBase):
    def __init__(self, result, successMessage, failMessage):
        if "errorMessage" in result:
            failMessage = result["errorMessage"]

        ResultBase.__init__(self, result["ok"] is True, successMessage, failMessage)


from .CommandBase import CommandBase
from .SessionCommandBase import SessionCommandBase

from .ResultBase import ResultBase
from .OkErrorCodeAndMessageResult import OkErrorCodeAndMessageResult
from .OkResult import OkResult
from .SimpleResult import SimpleResult


class ResultBase():
    def __init__(self, success, successMessage, failMessage):
        self.success = success
        if success is True:
            self.message = successMessage
        else:
            self.message = failMessage
    
    def getMessageForErrorCode(self, message, errorCode):
        return self.errorCodes(errorCode, message)

    def errorCodes(self, errorCode, message):
        return{
            11: message +": Invalid path",
            12: message +": File not found",
            13: message +": Bitmap buffer is empty\nDo 'captureReferenceBitmap()' or 'loadReferenceBitmap(filename)' first",
            14: message +": Timeout out of range",
            15: message +": Value out of range 0..100",
            16: message +": Region coordinates invalid",
            17: message +": Bitmap must have 24bpp RGB format",
            18: message +": Bitmap has the wrong size",
            19: message +": Cannot loaod bitmap",
            20: message +": Error while saving bitmap",
            21: message +": Region bitmap buffer empty\nDo 'captureReferenceBitmap()' and 'SetRegion(x, y, width, height)' first",
            22: message +": No capture engine available",
            160: message +": Error while applying filter",
            161: message +": Value out of range(-1000 to 1000)"
        }.get(errorCode,message)


class SessionCommandBase():
    def __init__(self, session, commandName):
        if session is None:
            raise Exception("session is required")
        if commandName is None:
            raise Exception("commandName is required")
            
        self.__session = session
        self.__commandName = commandName
        
    def executeCommand(self, requestObj, errorMessagePrefix):
        return self.__session.robot.executeCommand(self.__session.testRunId, " ", self.__commandName, requestObj, errorMessagePrefix)



class CommandBase():
    def __init__(self, testObject, commandName):
        if testObject is None:
            raise Exception("testObject is required")
        if commandName is None:
            raise Exception("commandName is required")
        
        self.__testObject = testObject
        self.__commandName = commandName

    def executeCommand(self, requestObj, errorMessagePrefix):
        return self.__testObject.executeCommand(self.__commandName, requestObj, errorMessagePrefix)



import json
import sys

from .ResultBase import ResultBase

class OkErrorCodeAndMessageResult(ResultBase):
    def __init__(self, result, successMessage, failMessage):
        ResultBase.__init__(self, result["ok"] is True, successMessage, failMessage)

        if self.success is True:
            return

        if "message" in result:
            self.message = result["message"]

        if "errorMessage" in result:
            self.message = result["errorMessage"]

        if "errorCode" in result:
            self.message = self.getMessageForErrorCode(self.message, result["errorCode"])


import json
import sys

from .ResultBase import ResultBase

class OkResult(ResultBase):
    def __init__(self, result, successMessage, failMessage):
        ResultBase.__init__(self, result["ok"] is True, successMessage, failMessage)